Module sensitive

Module sensitive 

Matching helpers for names that commonly carry secret values.

Structs

SecretKeyMatcher
Matches normalized key names that commonly carry secret values.

Constants

DEFAULT_SECRET_KEY_NAMES
Default key names that should usually be treated as secret-bearing.