#[non_exhaustive]pub enum TemplateError {
UnclosedPlaceholder(String),
UnmatchedClosingBrace(String),
EmptyPlaceholder,
UnknownPlaceholder(String),
Render(String),
MissingVariable(String),
}Expand description
Errors returned by template parsing and rendering.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnclosedPlaceholder(String)
The template has an unclosed placeholder (missing closing brace).
UnmatchedClosingBrace(String)
The template has an unmatched closing brace.
EmptyPlaceholder
A placeholder inside the template has an empty name.
UnknownPlaceholder(String)
A placeholder inside the template is not recognized.
Render(String)
A custom error returned by the renderer callback.
MissingVariable(String)
A dynamic variable required by the template had no value.